==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateHeader.cpp <==
/*!**********************************************************************

  module: StudioWeb_TemplateHeader.cpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  logo header for WebQuery

  see also:		/

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

/*-----------------------------------------------------------------------------
  includes
  -----------------------------------------------------------------------------*/
#include "SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateHeader.hpp"

/*
  -----------------------------------------------------------------------------
  defines
  -----------------------------------------------------------------------------
*/
#define TEMPLATE_NAME    "wqlogonmenu.htm"

#define OBJ_LOGOFF       "LogOff"


/*-----------------------------------------------------------------------------
  public constructor StudioWeb_TemplateHeader::StudioWeb_TemplateHeader
  -----------------------------------------------------------------------------*/
StudioWeb_TemplateHeader::StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa)
                       : SAPDBWeb_Template( wa, TEMPLATE_NAME),
                         m_bLogOff( SAPDB_FALSE)
{
} 

StudioWeb_TemplateHeader::StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa,
                                                 SAPDB_Bool         bLogOff)
                       : SAPDBWeb_Template( wa, TEMPLATE_NAME),
                         m_bLogOff( bLogOff)
{
} 
 
/*-----------------------------------------------------------------------------
  public destructor StudioWeb_TemplateHeader::~StudioWeb_TemplateHeader
  -----------------------------------------------------------------------------*/
StudioWeb_TemplateHeader::~StudioWeb_TemplateHeader()
{
} 


/*-----------------------------------------------------------------------------
  private functions ...
  -----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
  askForWriteCount
  -----------------------------------------------------------------------------*/
SAPDB_Int2 StudioWeb_TemplateHeader::askForWriteCount(const SAPDB_Char * szName)
{  
  if (strcmp(szName, OBJ_LOGOFF) == 0) 
    return ((m_bLogOff == SAPDB_TRUE) ? 1 : 0);
  
  return 0;
} 

/*-----------------------------------------------------------------------------
  askForValue
  -----------------------------------------------------------------------------*/
const SAPDBWeb_String StudioWeb_TemplateHeader::askForValue(const SAPDB_Char * szName)
{
  SAPDBWeb_String retval;
  return retval;
}

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateHeader.cpp <==
/*!**********************************************************************

  module: StudioWeb_TemplateHeader.cpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  logo header for WebQuery

  see also:		/

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

/*-----------------------------------------------------------------------------
  includes
  -----------------------------------------------------------------------------*/
#include "SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateHeader.hpp"

/*
  -----------------------------------------------------------------------------
  defines
  -----------------------------------------------------------------------------
*/
#define TEMPLATE_NAME    "wqlogonmenu.htm"

#define OBJ_LOGOFF       "LogOff"


/*-----------------------------------------------------------------------------
  public constructor StudioWeb_TemplateHeader::StudioWeb_TemplateHeader
  -----------------------------------------------------------------------------*/
StudioWeb_TemplateHeader::StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa)
                       : Tools_Template( wa, _Tools_UTF8Ptr(TEMPLATE_NAME)),
                         m_bLogOff( SAPDB_FALSE)
{
} 

StudioWeb_TemplateHeader::StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa,
                                                 SAPDB_Bool         bLogOff)
                       : Tools_Template( wa, _Tools_UTF8Ptr(TEMPLATE_NAME)),
                         m_bLogOff( bLogOff)
{
} 
 
/*-----------------------------------------------------------------------------
  public destructor StudioWeb_TemplateHeader::~StudioWeb_TemplateHeader
  -----------------------------------------------------------------------------*/
StudioWeb_TemplateHeader::~StudioWeb_TemplateHeader()
{
} 


/*-----------------------------------------------------------------------------
  private functions ...
  -----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
  askForWriteCount
  -----------------------------------------------------------------------------*/
SAPDB_Int2 StudioWeb_TemplateHeader::askForWriteCount(const Tools_DynamicUTF8String &szName)
{  
  if (szName.Compare( OBJ_LOGOFF) == 0) 
    return ((m_bLogOff == SAPDB_TRUE) ? 1 : 0);
  
  return 0;
} 

/*-----------------------------------------------------------------------------
  askForValue
  -----------------------------------------------------------------------------*/
Tools_DynamicUTF8String StudioWeb_TemplateHeader::askForValue(const Tools_DynamicUTF8String &szName)
{
  return Tools_DynamicUTF8String();
}
